﻿document.addEventListener("DOMContentLoaded", () => {
    translatePage();
});


var translations = null;
var allTranslations = null;

function resetTranslations() {
    translations = null;
    sessionStorage.removeItem("has_translations");
    sessionStorage.removeItem("translations");
}

function translatePage() {
    console.log("translatePage()");
    if (sessionStorage.getItem("has_translations") == null) {   

        console.log("has no translations yet");

        // check if user had any preference for the selected channel group
        var preferredLanguage = localStorage.getItem('preferredLanguage');
        if (preferredLanguage != "Default") {
            $.get("languages/" + preferredLanguage + ".json", function (data) {

                console.log("got translations");

                translations = data;
                sessionStorage.setItem("translations", JSON.stringify(translations));
                translatePage();
            });
        }
        else {
            console.log("no translations required");
        }
        sessionStorage.setItem("has_translations", "true");
    }
    else {    
        if (translations == null) {
            var json = sessionStorage.getItem("translations");
            if (json != null) {
                translations = JSON.parse(json);
            }
        }
        if (translations != null) {
            $('.translate').each(function (i, obj) {
                var originalText = ($(this).text());
                var translatedText = _T(originalText);
                if (originalText != translatedText) {
                    $(this).text(translatedText);
                    if (this.hasOwnProperty("placeholder") && this["placeholder"] != "") {
                        this.attr("placeholder", "");
                        this.attr("placeholder", translatedText);
                    }
                }
                $(this).removeClass("translate");
            });
        }
    }
}

function _T(originalText) {
   
    // if no translations enabled, just return original text
    if (translations == null) {
        return originalText;
    }

    // default to original text, but override if defined
    translated = originalText;
    if (translations.hasOwnProperty(originalText)) {
        translated = translations[originalText];
    }

    /*
    if (allTranslations == null) {
        var json = sessionStorage.getItem("all-translations");
        if (json != null) {
            allTranslations = JSON.parse(json);
        }
        if (allTranslations == null) {
            allTranslations = {};
        }
    }
    allTranslations[originalText] = "[" + originalText + "]";
    sessionStorage.setItem("all-translations", JSON.stringify(allTranslations));
    */
    return translated;
}

function getParameterByName(name, defaultValue) {
    name = name.replace(/[\[]/, "\\\[").replace(/[\]]/, "\\\]");
    var regexS = "[\\?&]" + name + "=([^&#]*)";
    var regex = new RegExp(regexS);
    var results = regex.exec(window.location.href);
    if (results === null)
        return defaultValue;
    else
        return decodeURIComponent(results[1].replace(/\+/g, " "));
}

Date.prototype.toLocaleDateString = function () {
    if (navigator.language == "en-US" || navigator.language == "en-CA") {
        return (this.getMonth() + 1) + "/" + this.getDate() + "/" + this.getFullYear()
    }
    return this.getDate() + "/" + (this.getMonth() + 1) + "/" + this.getFullYear()
};

function checkSession() {
    $.ajax({
        url: 'service?method=session.valid&format=json',
        type: 'GET',        
        contentType: 'application/json',
        success: function (data) {            
            console.log(data);
            if (data.stat != "ok") {
                var seconds = Math.round(new Date().getTime() / 1000);
                var url = new URL(window.location.href);
                url.searchParams.set('t', seconds);                
                console.log("session is not active");
                window.location.href = url;
            }
        },
        error: function (error) {
            console.log("failed checking session. server running?");
        }
    });
}

function promptForEPGUpdate() {
    var messageModal = app.__vue__.$refs.messageModal;
    messageModal.showMessage("Update EPG", "Your channel lineup has changed. Would you like to update your EPG now?", "Update EPG", "Not now");
}

function showMessageCallback(button) {
    if (button == "Update EPG") {
        var modal = app.__vue__.$refs.updateEPGModal;
        modal.updateEPG();
    }
}

function showConfirmationMessage(title, body, button1, button2, button1Callback, button2Callback) {
    var messageModal = app.__vue__.$refs.messageModal;
    messageModal.showMessage(title, body, button1, button2, button1Callback, button2Callback);
}

function lightOrDark(color) {

    // Variables for red, green, blue values
    var r, g, b, hsp;

    // Check the format of the color, HEX or RGB?
    if (color.match(/^rgb/)) {

        // If HEX --> store the red, green, blue values in separate variables
        color = color.match(/^rgba?\((\d+),\s*(\d+),\s*(\d+)(?:,\s*(\d+(?:\.\d+)?))?\)$/);

        r = color[1];
        g = color[2];
        b = color[3];
    }
    else {

        color = +("0x" + color.slice(1).replace(
            color.length < 5 && /./g, '$&$&'));

        r = color >> 16;
        g = color >> 8 & 255;
        b = color & 255;
    }

    // HSP (Highly Sensitive Poo) equation from http://alienryderflex.com/hsp.html
    hsp = Math.sqrt(
        0.299 * (r * r) +
        0.587 * (g * g) +
        0.114 * (b * b)
    );

    // Using the HSP value, determine whether the color is light or dark
    if (hsp > 127.5) {

        return 'light';
    }
    else {

        return 'dark';
    }
}


function parseISOString(s) {
    var b = s.split(/\D+/);
    return new Date(Date.UTC(b[0], --b[1], b[2], b[3], b[4], b[5], b[6]));
}

